@@ -9,14 +9,22 @@ from human_readable.numbers import int_comma
 from human_readable.numbers import int_word
 from human_readable.numbers import ordinal
 from human_readable.numbers import scientific_notation
+from human_readable.times import date
 from human_readable.times import date_time
+from human_readable.times import day
 from human_readable.times import precise_delta
+from human_readable.times import time_delta
+from human_readable.times import time_of_day
+from human_readable.times import timing
+from human_readable.times import year
 
 
 __all__ = [
     "activate",
     "ap_number",
+    "date",
     "date_time",
+    "day",
     "deactivate",
     "file_size",
     "fractional",
@@ -26,4 +34,8 @@ __all__ = [
     "ordinal",
     "precise_delta",
     "scientific_notation",
+    "time_delta",
+    "time_of_day",
+    "timing",
+    "year",
 ]
